@@ -40,5 +40,4 @@ def _activate_virtualenv(uranium_dir):
     """ this will activate a virtualenv in the case one exists """
     activate_this_path = os.path.join(uranium_dir, 'bin', 'activate_this.py')
     with open(activate_this_path) as fh:
-        code = compile(fh.read(), activate_this_path, 'exec')
-        exec(code, {}, {})
+        exec(fh.read(), {'__file__': activate_this_path}, {})
